.. comment This file was automatically generated by xrst

xrst
####

.. toctree::
   :maxdepth: 1

   xrst_search
   xrst_index
   xrst_contents
   example
   purpose
   user-guide
   release_notes
   module
